#!/bin/sh
# This script should be called from connector_manager.sh, and accepts the following parameters:
#  start_myconnector.sh <CONNECTORNAME> <SERVERNAME> <OPTIONAL ADDITIONAL PARAMETERS>
#
#  Any line that has the #   <-- Check on it should be reviewed for your connector
#
#The file CWConnEnv.sh defines the following in it's classpath, so there is no need to override any of these:
#Please go look at this file, on the solaris build, it is in the $CROSSWORLDS/setup directory.
#All of these are bundled together into the CLASSPATH variable which is then exported for your use
#It defines things such as:
#CORECW
#RSA 
#CWUTILS 
#XML_PARSER 
#DATAHANDLERS 
#MQ 
#ORB1 
#ORB2 
#JVM_FLAGS 
#JRT 
#JAVA_SECURITY 
#WEBLOGIC 
#
#################################################
# General connector variable initialization section
# No changes should be necessary
# set CONNECTOR_TYPE  -- This is needed to differentate Java from C++ conncetors 
# set CONDIR  the directory where the specific connector resides, then change to this directory
# set CONNAME the name to be the application connector that is starting
# set SERVER  the server name to be the interchange that is being targeted
# set CONJAR to the fullpath of the connector .jar file.

CONNAME=$1
SERVER=$2
. ${CROSSWORLDS}/bin/CWConnEnv.sh
echo $CWCLASSES
CONDIR=${CROSSWORLDS}/connectors/${CONNAME}
if [ "${OS}" = "SUNOS" ]
then
LD_LIBRARY_PATH=${CONDIR}:${LD_LIBRARY_PATH}
export LD_LIBRARY_PATH
elif [ "${OS}" = "HP-UX" ]
then
SHLIB_PATH=${CONDIR}:${SHLIB_PATH}
export SHLIB_PATH
else
LIBPATH=${CONDIR}:${LIBPATH}
export LIBPATH
fi




################################################
# Connector specific variable initialization section
# Set your Connector agent here 

#The following two sections tell the script what language the connector was written in,
# and help it make the correct calls. 
#Please enable one of the next sections

#For C++ connectors enable the following
#CONNECTOR_TYPE="-d"                                                             #   <-- Check
#CONNECTOR_AGENT=${CONNAME}                                                      #   <-- Check
#CONJAR=""
#LOCAL_JVM_FLAGS=${CONN_CPP_JVM_FLAGS}

#For Java connectors enable the following
CONNECTOR_TYPE="-l"                                                                     #   <-- Check
CONNECTOR_AGENT=com.crossworlds.connectors.Siebel.SiebelConnectorAgent    #   <-- Check
CONJAR=${CONDIR}/CW${CONNAME}.jar
#LOCAL_JVM_FLAGS=${CONN_JAVA_JVM_FLAGS}


# Set any connector specific Variables here
#CON_SPEC_JAR_ONE=${CONDIR}/abc.jar                                               #   <-- Check
#CON_SPEC_JAR_TWO=${CONDIR}/def.jar                                               #   <-- Check


# Set Conn specific classpath here 
#Any specific variables defined above need to be added to the CON_SPECIFIC_CLASSPATH below.
CON_SPECIFIC_CLASSPATH=${CON_SPEC_JAR_ONE}:${CON_SPEC_JAR_TWO}

# Set any Connector specific start options here (Like -t or -fno etc.)
CON_START_OPTIONS=" "                                                            #   <-- Check

# set the SIEBELAPPJARPATH to the directory where the Siebel App Jar files are stored.
# By default it would be ${CROSSWORLDS}/connectors/Siebel/dependencies

SIEBELAPPJARPATH=${CROSSWORLDS}/connectors/Siebel/dependencies

SIEBELAPP6x_JAR1=${SIEBELAPPJARPATH}/SiebelDataBean.jar
SIEBELAPP6x_JAR2=${SIEBELAPPJARPATH}/SiebelTC_enu.jar
SIEBELAPP6x_JAR3=${SIEBELAPPJARPATH}/SiebelTcCommon.jar
SIEBELAPP6x_JAR4=${SIEBELAPPJARPATH}/SiebelTcOM.jar
SIEBELAPP7x_JAR5=${SIEBELAPPJARPATH}/SiebelJI_enu.jar

#If the siebel application version is 7.7.x or 7.8.x, comment out the line below by adding # at the beginning
SIEBELAPP7x_JAR6=${SIEBELAPPJARPATH}/SiebelJI_Common.jar

#If the siebel application version is 7.7.x or 7.8.x, uncomment the line below by removing # at the beginning
#SIEBELAPP7x_JAR7=${SIEBELAPPJARPATH}/Siebel.jar


#Add any locale specific jar files. Add the same to CWCLASSES for 6.x and 7.x versions.
SIEBELAPP6x_JPN=${SIEBELAPPJARPATH}/SiebelTC_jpn.jar
SIEBELAPP7x_JPN=${SIEBELAPPJARPATH}/SiebelJI_jpn.jar

#Set the Siebel Version properly. By Default it would be 7.x

SIEBELVERSION=7.x

CWCLASSES=${CWCLASSES}:${SIEBELAPP7x_JAR5}:${SIEBELAPP7x_JAR6}:${SIEBELAPP7x_JAR7}:${SIEBELAPP7x_JPN}

#If the Siebel Version is 6.x, remove the '#' symbol in the line below

#SIEBELVERSION=6.x

if [ "$SIEBELVERSION" = "6.x" ]; then

	CWCLASSES=${CWCLASSES}:${SIEBELAPP6x_JAR1}:${SIEBELAPP6x_JAR2}:${SIEBELAPP6x_JAR3}:${SIEBELAPP6x_JAR4}:${SIEBELAPP6x_JPN}

fi

# We are using the JVM_FLAGS that are set in the CWSharedEnv.sh file, if you need to use different flags,
#  Change $JVM_FLAGS to be what you need to use.
# No changes should be necessary below this line.

if [ -f ${CROSSWORLDS}/wbiart/wbiart.jar ]
then

JCLASSES=${CONJAR}:${CON_SPECIFIC_CLASSPATH}:${CWCLASSES}
export JCLASSES
if [ "${OS}" = "SUNOS" ] | [ "${OS}" = "HP-UX" ]
then
JVMArgs="-Dfile.encoding=ISO8859_1"
export JVMArgs
fi
exec start_adapter.sh ${CONNECTOR_TYPE}${CONNECTOR_AGENT} -n${CONNAME}Connector -s${SERVER} ${CON_START_OPTIONS} $3 $4 $5 $6 $7 $8 $9

else

CWCLASSES=${CWCLASSES}
CLASSPATH=${CONJAR}:${CON_SPECIFIC_CLASSPATH}:${CWCLASSES}
echo $CLASSPATH
${CROSSWORLDS}/bin/check_path.sh "$CLASSPATH"
if [ "${OS}" = "SUNOS" ]
then
exec ${CWJAVA} ${JVM_FLAGS} -Xms64m -Djava.library.path=${MQ_LIB}:${LD_LIBRARY_PATH}  -Dfile.encoding="ISO8859_1" -Djava.ext.dirs=${MQ_LIB}:${JRE_EXT_DIRS} -classpath ${CLASSPATH}  AppEndWrapper ${CONNECTOR_TYPE}${CONNECTOR_AGENT} -n${CONNAME}Connector -s${SERVER} ${CON_START_OPTIONS}  $3 $4 $5 $6 $7 $8 $9
elif [ "${OS}" = "HP-UX" ]
then
exec ${CWJAVA} ${JVM_FLAGS} -Xms64m -Djava.library.path=${MQ_LIB}:${SHLIB_PATH}  -Dfile.encoding="ISO8859_1" -Djava.ext.dirs=${MQ_LIB}:${JRE_EXT_DIRS} -classpath ${CLASSPATH}  AppEndWrapper ${CONNECTOR_TYPE}${CONNECTOR_AGENT} -n${CONNAME}Connector -s${SERVER} ${CON_START_OPTIONS} $3 $4 $5 $6 $7 $8 $9
else
exec ${CWJAVA} ${JVM_FLAGS} -Xms64m -Djava.library.path=${MQ_LIB}:${LIBPATH} -Djava.ext.dirs=${MQ_LIB}:${JRE_EXT_DIRS} -classpath ${CLASSPATH}  AppEndWrapper ${CONNECTOR_TYPE}${CONNECTOR_AGENT} -n${CONNAME}Connector -s${SERVER} ${CON_START_OPTIONS}  $3 $4 $5 $6 $7 $8 $9
fi
fi
